pub struct ControlLabel { /* private fields */ }Available on crate feature
yew only.Expand description
A drop-in label wrapper for Radio, Switch, and Checkbox controls.
Renders a <label> element that wraps a control (<input type="checkbox">,
etc.) alongside descriptive label text. The label_placement prop controls
the visual order of the control and its label.
Accessibility
- The wrapping
<label>element natively associates its text with the contained control, so no explicitforattribute is needed. aria-disabledis set whendisabledistrue.aria-requiredis set whenrequiredistrue.
Examples
use form_rs::yew::ControlLabel;
use form_rs::LabelPlacement;
use yew::prelude::*;
#[function_component(TermsCheckbox)]
pub fn terms_checkbox() -> Html {
html! {
<ControlLabel
control={html! { <input type="checkbox" /> }}
label={html! { <span>{"I agree to the terms"}</span> }}
label_placement={LabelPlacement::End}
/>
}
}Trait Implementations
Sourceimpl BaseComponent for ControlLabelwhere
Self: 'static,
impl BaseComponent for ControlLabelwhere
Self: 'static,
Sourcetype Properties = ControlLabelProps
type Properties = ControlLabelProps
The Component’s Properties.
Sourcefn update(&mut self, _ctx: &Context<Self>, _msg: Self::Message) -> bool
fn update(&mut self, _ctx: &Context<Self>, _msg: Self::Message) -> bool
Updates component’s internal state.
Sourcefn changed(
&mut self,
_ctx: &Context<Self>,
_old_props: &Self::Properties,
) -> bool
fn changed( &mut self, _ctx: &Context<Self>, _old_props: &Self::Properties, ) -> bool
React to changes of component properties.
Sourcefn view(&self, ctx: &Context<Self>) -> HtmlResult
fn view(&self, ctx: &Context<Self>) -> HtmlResult
Returns a component layout to be rendered.
Sourcefn rendered(&mut self, _ctx: &Context<Self>, _first_render: bool)
fn rendered(&mut self, _ctx: &Context<Self>, _first_render: bool)
Notified after a layout is rendered.
Sourcefn prepare_state(&self) -> Option<String>
fn prepare_state(&self) -> Option<String>
Prepares the server-side state.
Sourceimpl Debug for ControlLabel
impl Debug for ControlLabel
Sourceimpl FunctionProvider for ControlLabel
impl FunctionProvider for ControlLabel
Sourcetype Properties = ControlLabelProps
type Properties = ControlLabelProps
Properties for the Function Component.
Sourcefn run(ctx: &mut HookContext, props: &Self::Properties) -> HtmlResult
fn run(ctx: &mut HookContext, props: &Self::Properties) -> HtmlResult